.. moduleauthor:: Paul Ross <apaulross@gmail.com>
.. sectionauthor:: Paul Ross <apaulross@gmail.com>

.. TotalDepth API reference.

Plot Package Reference
==========================

Contents:

.. toctree::
	:maxdepth: 2

	AREACfg
	Coord
	FILMCfg
	FILMCfgXML
	LogHeader
	Plot
	PlotConstants
	PRESCfg
	PRESCfgXML
	Stroke
	SVGWriter
	Track
	XGrid
	XMLCfg
	XMLMatches
